package com.bosch.myspin.serversdk.navigation;

/**
 * INavigation service interface for navigate to feature. This class provides methods for the ServerSDK in order
 * to provide the navigate to feature.
 *
 * @author Burim Kameri
 * @since 2014-06-16
 */
interface INavigation
{
	/**
	 * Check if there the NavigateTo feature is available.
	 * If there are no navigation apps available, -1 is returned.
	 * If there is no myspin connection, -2 is returned. Otherwise (the feature
	 * is ready to use), 0 is returned.
	 */
	int getNavigateToState();

	/**
	 * Initiate a navigation request to an myspin navigation capable app with supplied
	 * destinationLocation. Use destinationDescription for the destination.
	 *
	 * @return True if the initiation was successful, otherwise false
	 */
	boolean initiateNavigationByLocation(in Location destinationLocation, String destinationDescription);

	/**
	 * Initiates a navigate to request. mySPIN navigation capable may response to this request and start a navigation
	 * with supplied arguments.
	 *
	 * @param placemark
	 *            Placemark filter of the destination.
	 * @return True if the navigation has been requested successfully, otherwise false. Depends on the
	 *         {@link #getNavigationCapabilityState() result}
	 */
	boolean initiateNavigationByAddress(in Bundle placemark);
}
