package com.bosch.myspin.serversdk.service;

interface IMySpinServiceClient 
{
	/**
	 * Will be called to request the latest frame from the visible activity. 
	 */
	oneway void onFrameRequest();

	/**
	 * Will be called if the connection to an myspin client has been established or lost.
	 */
	oneway void onConnectionStateChanged(boolean isConnected);

	/**
	 * Will be called initially at first connection (after onConnectionStateChanged) and optional during the runtime.
	 */
	oneway void onMySpinClientDataChanged(in Bundle changedDataBundle);
	
	/**
	 * Will be called of one or more touch events have been received from an myspin client.
	 */
	oneway void onTouchEvent(in int[] type, in int[] x, in int[] y, in int[] id, in int numTouches);
	
	/**
	 * Will be called when the back button has been pressed on a myspin client.
	 */
	oneway void onBackButtonPressed();
	
	/**
	 * Will be called when the menu button has been pressed on a myspin client.
	 */
	oneway void onMenuButtonPressed();
	
	/**
	 * Will be called phone call state has been changed.
	 * 
	 * @param phoneCallState enum values of received phone status.
	 */	
	oneway void onPhoneCallStateChanged( int phoneCallState );
	
	/**
	 * Will be called when restriction flag has been updated 
	 *
	 * @param isRestricted boolean value to indicate if the App is restricted 
	 */
	 oneway void onRestrictionDidUpdate(boolean isRestricted);
	

}
