package com.bosch.myspin.serversdk.voicecontrol;

/**
 * IVoiceControl service interface TODO.
 *
 * @author Johannes Steudle
 * @since 2014-08-25
 */
interface IVoiceControl
{
	/**
	 * This method requests voice control from the connected IVI. Response is sent via IVoiceControlStateListener.
	 *
	 * @param voiceControlRequestType
	 *            The voice request type. Possible types are: MicAndSpeakers, MicOnly
	 */
	void requestVoiceControl(int voiceControlRequestType);

	/**
	 * Use this method to retrieve information about voice control capability of the IVI. It is not possible to get
	 * access to voice control with this method, this has to be requested with {@link #requestVoiceControl()}.
	 * Possible states are:
	 * NotSupported, VirtualPhoneCallOnly, FullSCOSupport
	 *
	 * @return Returns the voice control capability
	 */
	boolean hasVoiceControlCapability();

	/**
	 * This method sends a stop voice control to the connected IVI. This means the app does not require voice control
	 * anymore. There is no response to this request, so the app should stop recording immediately.
	 *
	 * @param voiceControlResignType
	 *            The VoiceControl resign type. Possible types are: EndUserEvent = 3 and EndRealCallEvent = 4
	 */
	void resignVoiceControl(int voiceControlResignType);
	
	/**
	 * This method sets the messenger to which the voice control response messages are send.
	 * @param onVoiceControlMessenger 
	 *                                 The messenger to register
	 */
	void setVoiceControlMessenger(IBinder onVoiceControlMessenger);
	
}
